.. toctree::
    :caption: User docs
    :maxdepth: 1

    user/basic
    user/profile
    user/translating
    user/files
    user/checks
    user/search
    devel/index
    workflows
    faq
    formats
    vcs
    api
    wlc
    python
